summaryrefslogtreecommitdiffstats
path: root/src/widgets/mesh-toolbar.cpp
diff options
context:
space:
mode:
authorLiam P. White <inkscapebrony@gmail.com>2014-12-21 15:39:39 +0000
committerLiam P. White <inkscapebrony@gmail.com>2014-12-21 15:39:39 +0000
commit30b6a43219b66aba1a9ebade8aca50910f2c25cc (patch)
treea34e3ffe54acd7ea8ff80b808c5995d71e255dae /src/widgets/mesh-toolbar.cpp
parentAdd arrow that demonstates 'auto-start-reverse' and 'context-stroke'/'context... (diff)
downloadinkscape-30b6a43219b66aba1a9ebade8aca50910f2c25cc.tar.gz
inkscape-30b6a43219b66aba1a9ebade8aca50910f2c25cc.zip
Deprecate and remove sp_desktop_selection in favor of SPDesktop::getSelection
(bzr r13809)
Diffstat (limited to 'src/widgets/mesh-toolbar.cpp')
-rw-r--r--src/widgets/mesh-toolbar.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/widgets/mesh-toolbar.cpp b/src/widgets/mesh-toolbar.cpp
index 897d84278..8c7ec33a8 100644
--- a/src/widgets/mesh-toolbar.cpp
+++ b/src/widgets/mesh-toolbar.cpp
@@ -92,7 +92,7 @@ static void ms_tb_selection_changed(Inkscape::Selection * /*selection*/, gpointe
// return;
// }
// Inkscape::Selection *selection = sp_desktop_selection(desktop); // take from desktop, not from args
// if (selection) {
// ToolBase *ev = sp_desktop_event_context(desktop);
// GrDrag *drag = NULL;
@@ -334,7 +334,7 @@ static void mesh_toolbox_watch_ec(SPDesktop* desktop, Inkscape::UI::Tools::ToolB
if (SP_IS_MESH_CONTEXT(ec)) {
// connect to selection modified and changed signals
- Inkscape::Selection *selection = sp_desktop_selection (desktop);
+ Inkscape::Selection *selection = desktop->getSelection();
SPDocument *document = sp_desktop_document (desktop);
c_selection_changed = selection->connectChanged(sigc::bind(sigc::ptr_fun(&ms_tb_selection_changed), holder));
@@ -92,7 +92,7 @@ static void ms_tb_selection_changed(Inkscape::Selection * /*selection*/, gpointe
// return;
// }
- // Inkscape::Selection *selection = sp_desktop_selection(desktop); // take from desktop, not from args
+ // Inkscape::Selection *selection = desktop->getSelection(); // take from desktop, not from args
// if (selection) {
// ToolBase *ev = sp_desktop_event_context(desktop);